From 2b1a0f0c452d07db5f856cdd98a81c9003cb77ab Mon Sep 17 00:00:00 2001
From: Massimiliano Adamo <massimiliano.adamo@geant.org>
Date: Sun, 11 Apr 2021 22:51:38 +0200
Subject: [PATCH] use exit status 64 to reload the application

---
 main.go | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/main.go b/main.go
index a1d2d42..9fca715 100644
--- a/main.go
+++ b/main.go
@@ -509,7 +509,7 @@ Options:
 	moveFile(tmpCaDestination, caDestination, GroupID, 0644, 0755)
 	moveFile(tmpKeyDestination, keyDestination, GroupID, 0640, 0750)
 
-	// Exit 1 means application needs to be reloaded
-	appExit(1)
+	// Exit 64 means application needs to be reloaded
+	appExit(64)
 
 }
-- 
GitLab